@@ -3,10 +3,11 @@ use 5.012;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 use Moo;
 use HTTP::Tiny '0.056';
 use JSON::Tiny qw[decode_json];
+use Try::Tiny;
 use strictures 2;
 use namespace::clean;
 use DateTime;
@@ -20,6 +21,7 @@ use Finance::Robinhood::Order;
 use Finance::Robinhood::Position;
 use Finance::Robinhood::Quote;
 use Finance::Robinhood::Watchlist;
+use Finance::Robinhood::Portfolio;
 #
 has token => (is => 'ro', writer => '_set_token');
 #
@@ -239,10 +241,16 @@ sub accounts {
 #
 # Returns the porfillo summery of an account by url.
 #
-#sub get_portfolio {
-#    my ($self, $url) = @_;
-#    return $self->_send_request('GET', $url);
-#}
+sub portfolios {
+    my ($self) = @_;
+
+    # TODO: Deal with next and previous results? Multiple portfolios?
+    my $return = $self->_send_request('GET',
+                                      Finance::Robinhood::endpoint('portfolios')
+    );
+    return $self->_paginate($return, 'Finance::Robinhood::Portfolio');
+
+}
 #
 # Return the positions for an account.
 # This is sort of a heavy call as it makes many API calls to populate all the data.
@@ -331,12 +339,13 @@ sub instrument {
 
 sub quote {
     my $self = ref $_[0] ? shift : ();    # might be undef but that's okay
-    #if (scalar @_ > 1 or wantarray) {
-        my $return =
-            _send_request($self, 'GET',
+                                          #if (scalar @_ > 1 or wantarray) {
+    my $return =
+        _send_request($self, 'GET',
               Finance::Robinhood::endpoint('quotes') . '?symbols=' . join ',',
               @_);
-        return _paginate($self, $return, 'Finance::Robinhood::Quote');
+    return _paginate($self, $return, 'Finance::Robinhood::Quote');
+
     #}
     #my $quote =
     #    _send_request($self, 'GET',
@@ -471,6 +480,14 @@ sub watchlist {
         : ();
 }
 
+sub markets {
+    my $self = ref $_[0] ? shift : ();    # might be undef but that's okay
+    my ($symbol, $interval, $span) = @_;
+    my $result = _send_request($self, 'GET',
+                               Finance::Robinhood::endpoint('markets'));
+    return _paginate($self, $result, 'Finance::Robinhood::Market');
+}
+
 # ---------------- Private Helper Functions --------------- //
 # Send request to API.
 #
@@ -482,13 +499,14 @@ sub _paginate {    # Paginates results
         : ();
     my ($next)
         = defined $res->{next} ? ($res->{next} =~ m[\?cursor=(.+)$]) : ();
+
     return {
         results => (
             defined $class ?
                 [
                 map {
                     $class->new(%$_, ($self ? (rh => $self) : ()))
-                } @{$res->{results}}
+                } grep {defined} @{$res->{results}}
                 ]
             : $res->{results}
         ),
@@ -566,7 +584,15 @@ sub _send_request {
 
     #ddx $res;
     #warn $res->{content};
-    my $rt = $json ? decode_json($json) : ();
+    my $rt = $json ?
+        try {
+        decode_json($json)
+    }
+    catch {
+        warn "caught error: $_";
+        ()
+    }
+    : ();
 
     # Return happy.
     return wantarray ? ($res->{status}, $rt, $res) : $rt;
@@ -580,11 +606,11 @@ sub _2_datetime {
     DateTime->new(year  => $1,
                   month => $2,
                   day   => $3,
-                  (defined $7 ? (hour       => $4) : ()),
-                  (defined $7 ? (minute     => $5) : ()),
-                  (defined $7 ? (second     => $6) : ()),
+                  (defined $4 ? (hour       => $4) : ()),
+                  (defined $5 ? (minute     => $5) : ()),
+                  (defined $6 ? (second     => $6) : ()),
                   (defined $7 ? (nanosecond => $7) : ()),
-                  (defined $7 ? (time_zone  => $8) : ())
+                  (defined $8 ? (time_zone  => $8) : ())
     );
 }
 1;
